@@ -1,7 +1,8 @@
 from tests.collection import CollectionTest
 from tests.snapshot import SnapshotTest
 from tests.retention import RetentionPolicyTest
+from tests.conf import ConfTest
 from tests.ctl.client import ClientTest, TokenAuthClientTest
 from tests.ctl.file import FileTest
 
-__all__ = ['CollectionTest', 'SnapshotTest', 'RetentionPolicyTest', 'ClientTest', 'TokenAuthClientTest', 'FileTest']
+__all__ = ['CollectionTest', 'SnapshotTest', 'RetentionPolicyTest', 'ClientTest', 'TokenAuthClientTest', 'FileTest', 'ConfTest']
